%global project opencontainers
%global repo runc
%global goipath github.com/%{project}/%{repo}
%global debug_package %{nil}

#debuginfo not supported with Go
%global gopath  %{_libdir}/golang
%define gosrc %{gopath}/src/pkg/%{goipath}

Name:           %{project}-%{repo}
Epoch:          1
Version:        1.1.9
Release:        %mkrel 1
Summary:        runc container cli tools
License:        ASL 2.0
Group:          System/Configuration

URL:            https://www.opencontainers.org/
Source0:		https://%{goipath}/archive/v%{version}.tar.gz


BuildRequires:  gcc
BuildRequires:  glibc-static-devel
BuildRequires:  pkgconfig(libseccomp)

# ensure build uses golang 1.13 or above
BuildRequires:  golang >= 1.13
Provides: oci-runtime = 2

%package devel
Summary:		runc container devel files
Provides:		golang(%{name}) = %{version}-%{release}

%description devel
This is the source libraries for runC

%description
runc is a CLI tool for spawning and running containers according to the OCI specification.

%gopkg

%prep
%autosetup -n %{repo}-%{version} -p1

%build
export GOPATH=$(pwd)/Godeps/_workspace:%{gopath}
ln -sf $(pwd)/vendor $(pwd)/src
mkdir -p $(pwd)/vendor/github.com/opencontainers/runc
cp -a libcontainer $(pwd)/vendor/github.com/opencontainers/runc
cp -a types $(pwd)/vendor/github.com/opencontainers/runc
export GOPATH=$(pwd):%{gopath}
rm -f go.mod
export GO111MODULE=off
make BUILDTAGS="seccomp selinux"

%install
# Fix for gopkginstall
ln -sf . _build
# install binary
install -d %{buildroot}%{_bindir}
install -p -m 755 runc %{buildroot}%{_bindir}
cd %{buildroot}%{_bindir}
for i in *; do
	ln -sf $i docker-$i
done
# Setup for gopkginstall
%global extractdir0 %{repo}-%{version}
%gopkginstall -v

%files
%doc CONTRIBUTING.md MAINTAINERS* PRINCIPLES.md README.md
%license LICENSE NOTICE
%{_bindir}/*

%files devel
%{_libdir}/golang/src/%{goipath}


%changelog
* Wed Aug 30 2023 bcornec <bcornec> 1:1.1.9-1.mga9
+ Revision: 1981844
- Update for docker stack

* Wed Mar 29 2023 bcornec <bcornec> 1:1.1.5-1.mga9
+ Revision: 1950600
- Update to upstream opencontainers-runc 1.1.5 to fix CVE-2023-25809 CVE-2023-27561 CVE-2023-28642

* Tue Dec 13 2022 bcornec <bcornec> 1:1.1.4-2.mga9
+ Revision: 1921647
- Update to upstream 1.1.4 and generate devel files properly for docker-containerd

* Sun Oct 02 2022 joequant <joequant> 1:1.1.4-1.mga9
+ Revision: 1893767
- update to 1.1.4

* Sat May 14 2022 bcornec <bcornec> 1:1.1.2-2.mga9
+ Revision: 1858100
- Update to upstream opencontainers-runc 1.1.2 to fix mga#30421

* Fri Mar 25 2022 umeabot <umeabot> 1:1.0.3-2.mga9
+ Revision: 1827055
- Mageia 9 Mass Rebuild

* Wed Dec 08 2021 bcornec <bcornec> 1:1.0.3-1.mga9
+ Revision: 1761078
- Fix mga#29738 by updating opencontainers-runc to upstream 1.0.3

* Wed Aug 25 2021 bcornec <bcornec> 1:1.0.2-1.mga9
+ Revision: 1742547
- Update to upstream opencontainer runc 1.0.2

* Sat May 29 2021 bcornec <bcornec> 1:1.0.0-0.rc95.2.dev.gitb23315b.mga9
+ Revision: 1728767
- Update to upstream 1.0.0rc95

* Sun Apr 11 2021 joequant <joequant> 1:1.0.0-0.rc93.2.dev.gitb23315b.mga9
+ Revision: 1714794
- add oci-runtime provides

* Sun Apr 11 2021 joequant <joequant> 1:1.0.0-0.rc93.1.dev.gitb23315b.mga9
+ Revision: 1714788
- update to latest with fix to podman perm issue
  has fix to https://github.com/containers/podman/issues/9725

* Sun Nov 01 2020 bcornec <bcornec> 1:1.0.0-0.rc92.7.dev.gitff819c7.mga8
+ Revision: 1641125
- update to upstream opencontainer runc 1.0.0 rc92

* Sat Apr 11 2020 joequant <joequant> 1:1.0.0-0.rc10.7.dev.gitccbb336.mga8
+ Revision: 1566291
- add libseccomp to buildrequires
- update to latest git revision
- fix typo
- add selinux and seccomp tags

* Sun Feb 23 2020 bcornec <bcornec> 1:1.0.0-0.rc10.4.mga8
+ Revision: 1549504
- Update to runc-1.0.0-rc10 to fix mga#26173

* Wed Feb 19 2020 umeabot <umeabot> 1:1.0.0-0.rc9.4.mga8
+ Revision: 1543454
- Mageia 8 Mass Rebuild

* Mon Jan 20 2020 bcornec <bcornec> 1:1.0.0-0.rc9.3.mga8
+ Revision: 1481637
- Update opencontainers-runc to upstream 1.0rc9 to fix CVE-2019-16884

* Wed Sep 04 2019 bcornec <bcornec> 1:1.0.0-0.rc8.3.mga8
+ Revision: 1437233
- update to upstream v1.0.0rc8 opencontainers-runc

* Tue Feb 12 2019 luigiwalser <luigiwalser> 1:1.0.0-0.rc6.3.mga7
+ Revision: 1365382
- add upstream patch to fix CVE-2019-5736

* Sat Feb 02 2019 luigiwalser <luigiwalser> 1:1.0.0-0.rc6.2.mga7
+ Revision: 1362659
- add upstream pull request 1962 to fix security issue (mga#25253, rhbz#1663068)

* Sun Jan 20 2019 ngompa <ngompa> 1:1.0.0-0.rc6.1.mga7
+ Revision: 1358469
- Upgrade to runc-1.0.0-rc6
- Add Epoch to fix broken version scheme
- Add patch from Fedora to allow sd_notify to work with runc and podman

* Tue Oct 16 2018 bcornec <bcornec> 1.0.0rc5-3.mga7
+ Revision: 1320896
- SILIENT: update sha1
- update to upstream 1.0.0rc5 opencontainers-runc

* Sun Sep 23 2018 umeabot <umeabot> 1.0.0rc2-3.mga7
+ Revision: 1299988
- Mageia 7 Mass Rebuild

* Sun May 28 2017 akien <akien> 1.0.0rc2-2.mga6
+ Revision: 1105408
- Rebuild against fixed golang
+ bcornec <bcornec>
- Go back to rc2 build procedure for opencontainers-runc
- go back to rc2 of opencontainers-runc as rc3 doesn't work with docker 17.03
- update to upstream 1.0.0rc3

* Thu Nov 24 2016 bcornec <bcornec> 1.0.0rc2-1.mga6
+ Revision: 1069706
- update to upstream 1.0.0rc2

* Sat Sep 24 2016 bcornec <bcornec> 1.0.0rc1-1.mga6
+ Revision: 1055669
- Update to upstream 1.0.rc1 needed by docker 0.12.1

* Mon May 23 2016 bcornec <bcornec> 0.1.1-2.mga6
+ Revision: 1018001
- remove restriction on arch

* Sun May 22 2016 bcornec <bcornec> 0.1.1-1.mga6
+ Revision: 1017692
- Create an opencontainers-runc package needed by docker >= 1.11
- Created package structure for opencontainers-runc.

